==> dLagM_0.0.7.tar.gz: dLagM/man/polyDlm.Rd <==
\name{polyDlm}
\alias{polyDlm}

\title{
Implement finite polynomial distributed lag model
}
\description{
A function that applies polynomial distributed lag models with one predictor.
}
\usage{
polyDlm(x , y , q , k , show.beta = TRUE , show.summary = TRUE)
}
\arguments{
  \item{x}{
  A vector including the observations of predictor time series. This is not restricted to \code{ts} objects.
  }
  \item{y}{
  A vector including the observations of dependent time series. This is not restricted to \code{ts} objects.
  } 
  \item{q}{
  An integer representing finite lag length.
  }  
  \item{k}{
  An integer representing order of polynomial distributed lags.
  }
  \item{show.beta}{
  If \code{TRUE}, generates original beta parameters and associate t-tests and prints the results.
  }
\item{show.summary}{
  If \code{TRUE}, prints standard model summary for the model of interest.
  }  
 
}
\details{
When a decision made on a variable, some of the related variables would be effected through time. For example, when income tax rate is increased, this would reduce expenditures of consumers on goods and services, which reduces profits of suppliers, which reduces the demand for productive inputs, which reduces the profits of the input suppliers, and so on (Judge and Griffiths, 2000). These effects occur over the future time periods; hence, they are distributed across the time.    

In a distributed-lag model, the effect of an independent variable \eqn{X} on a dependent variable \eqn{Y} occurs over the time. Therefore, DLMs are dynamic models. A linear finite DLM with one independent variable is written as follows:


\deqn{
      Y_{t} = \alpha +\sum_{s = 0}^{q}\beta_{s}X_{t-s}+\epsilon_{t},
      }

where \eqn{\epsilon_{t}} is a stationary error term with \eqn{E(\epsilon_{t})=0, Var(\epsilon_{t})=\sigma^{2},Cov(\epsilon_{t},\epsilon_{s})=0}.
}

\value{

\item{model}{An object of class \code{lm}. See the details of \code{href{https://stat.ethz.ch/R-manual/R-devel/library/stats/html/lm.html}{lm}} function.}

\item{designMatrix}{The design matrix composed of transformed z-variables.}

\item{designMatrix.x}{The design matrix composed of original x-variables.}

\item{beta.coefficients}{Estimates and t-tests of original beta coefficients. This will be generated if \code{show.beta} is set to \code{TRUE}.}
}

\references{
B.H. Baltagi. \emph{Econometrics}, Fifth Ed. Springer, 2011.

R.C. Hill, W.E. Griffiths, G.G. Judge. \emph{Undergraduate Econometrics}. Wiley, 2000. 
}

\author{
Haydar Demirhan

Maintainer: Haydar Demirhan <haydar.demirhan@rmit.edu.au>
}

\examples{
data(warming)
model.poly = polyDlm(x = warming$NoMotorVehicles , y = warming$Warming , 
q = 2 , k = 2 , show.beta = TRUE ,  show.summary = TRUE)
}

==> dLagM_1.0.0.tar.gz: dLagM/man/polyDlm.Rd <==
\name{polyDlm}
\alias{polyDlm}

\title{
Implement finite polynomial distributed lag model
}
\description{
A function that applies polynomial distributed lag models with one predictor.
}
\usage{
polyDlm(x , y , q , k , show.beta = TRUE , show.summary = TRUE)
}
\arguments{
  \item{x}{
  A vector including the observations of predictor time series. This is not restricted to \code{ts} objects.
  }
  \item{y}{
  A vector including the observations of dependent time series. This is not restricted to \code{ts} objects.
  } 
  \item{q}{
  An integer representing finite lag length.
  }  
  \item{k}{
  An integer representing order of polynomial distributed lags.
  }
  \item{show.beta}{
  If \code{TRUE}, generates original beta parameters and associate t-tests and prints the results.
  }
\item{show.summary}{
  If \code{TRUE}, prints standard model summary for the model of interest.
  }  
 
}
\details{
Finite distributed lag models, in general, suffer from the multicollinearity due to inclusion of the lags of the same variable in the model. To reduce the impact of this multicollinearity, a polynomial shape is imposed on the lag distribution (Judge and Griffiths, 2000). The resulting model is called Polynomial Distributed Lag model or Almond Distributed Lag Model. 

Imposing a polynomial pattern on the lag distribution is equivalent to representing \eqn{\beta} parameters with another $k$th order polynomial model of time. So, the effect of change in \eqn{X_{t-s}} on the expected value of \eqn{Y_{t}} is represented as follows:

\deqn{
  \frac{\partial E(Y_{t})}{\partial X_{t-s}}=\beta_{s}=\gamma_{0}+\gamma_{1}s+\gamma_{2}s^{2}+\cdots+\gamma_{k}s^{k}
}

where \eqn{s=0,\dots,q} (Judge and Griffiths, 2000). Then the model becomes:

\deqn{
  Y_{t} = \alpha +\gamma_{0}Z_{t0}+\gamma_{1}Z_{t1}+\gamma_{2}Z_{t2}+\cdots +\gamma_{k}Z_{tk}  + \epsilon_{t}.
}

}

\value{

\item{model}{An object of class \code{lm}.}

\item{designMatrix}{The design matrix composed of transformed z-variables.}

\item{designMatrix.x}{The design matrix composed of original x-variables.}

\item{beta.coefficients}{Estimates and t-tests of original beta coefficients. This will be generated if \code{show.beta} is set to \code{TRUE}.}
}

\references{
B.H. Baltagi. \emph{Econometrics}, Fifth Ed. Springer, 2011.

R.C. Hill, W.E. Griffiths, G.G. Judge. \emph{Undergraduate Econometrics}. Wiley, 2000. 
}

\author{
Haydar Demirhan

Maintainer: Haydar Demirhan <haydar.demirhan@rmit.edu.au>
}

\examples{
data(warming)
model.poly = polyDlm(x = warming$NoMotorVehicles , y = warming$Warming , 
q = 2 , k = 2 , show.beta = TRUE ,  show.summary = TRUE)
}
